@@ -15,8 +15,6 @@ Configuration = {
     "profile_sql_param_enabled": False,
     "hook_method_patterns": "",
 
-    "mtid": 0,
-    "httpc_checked": True,
     "mtrace_rate": 0,
     "mtrace_spec": '',
     "mtrace_send_url_length": 80,
