@@ -98,7 +98,7 @@ class TraceContext(object):
         return time - self.start_time
 
     def getCpuTime(self):
-        return int(time.clock_gettime(time.CLOCK_REALTIME))
+        return int(time.time())
 
     def getMemory(self):
         # https://docs.python.org/3/library/resource.html?highlight=resource#resource-usage
