@@ -5,7 +5,7 @@ try:
 except ImportError:
     find_loader = None
 
-from whatap.trace.trace_module_definication import IMPORT_HOOKS, PLUGIN
+from whatap.trace.trace_module_definition import IMPORT_HOOKS, PLUGIN
 
 from whatap import logging
 from whatap.conf.configure import Configure as conf
